developerscripttools.TestAndRebuildScript
=========================================

.. abjad-lineage:: abjad.tools.developerscripttools.TestAndRebuildScript.TestAndRebuildScript.TestAndRebuildScript

.. autoclass:: abjad.tools.developerscripttools.TestAndRebuildScript.TestAndRebuildScript.TestAndRebuildScript
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.developerscripttools.TestAndRebuildScript.TestAndRebuildScript.TestAndRebuildScript.alias
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.TestAndRebuildScript.TestAndRebuildScript.TestAndRebuildScript.argument_parser
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.TestAndRebuildScript.TestAndRebuildScript.TestAndRebuildScript.formatted_help
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.TestAndRebuildScript.TestAndRebuildScript.TestAndRebuildScript.formatted_usage
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.TestAndRebuildScript.TestAndRebuildScript.TestAndRebuildScript.formatted_version
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.TestAndRebuildScript.TestAndRebuildScript.TestAndRebuildScript.long_description
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.TestAndRebuildScript.TestAndRebuildScript.TestAndRebuildScript.program_name
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.TestAndRebuildScript.TestAndRebuildScript.TestAndRebuildScript.scripting_group
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.TestAndRebuildScript.TestAndRebuildScript.TestAndRebuildScript.short_description
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.TestAndRebuildScript.TestAndRebuildScript.TestAndRebuildScript.storage_format
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.TestAndRebuildScript.TestAndRebuildScript.TestAndRebuildScript.version
   :noindex:

Methods
-------

.. automethod:: abjad.tools.developerscripttools.TestAndRebuildScript.TestAndRebuildScript.TestAndRebuildScript.get_terminal_width
   :noindex:

.. automethod:: abjad.tools.developerscripttools.TestAndRebuildScript.TestAndRebuildScript.TestAndRebuildScript.process_args
   :noindex:

.. automethod:: abjad.tools.developerscripttools.TestAndRebuildScript.TestAndRebuildScript.TestAndRebuildScript.rebuild_docs
   :noindex:

.. automethod:: abjad.tools.developerscripttools.TestAndRebuildScript.TestAndRebuildScript.TestAndRebuildScript.run_doctest
   :noindex:

.. automethod:: abjad.tools.developerscripttools.TestAndRebuildScript.TestAndRebuildScript.TestAndRebuildScript.run_pytest
   :noindex:

.. automethod:: abjad.tools.developerscripttools.TestAndRebuildScript.TestAndRebuildScript.TestAndRebuildScript.setup_argument_parser
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.developerscripttools.TestAndRebuildScript.TestAndRebuildScript.TestAndRebuildScript.__call__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.TestAndRebuildScript.TestAndRebuildScript.TestAndRebuildScript.__eq__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.TestAndRebuildScript.TestAndRebuildScript.TestAndRebuildScript.__ge__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.TestAndRebuildScript.TestAndRebuildScript.TestAndRebuildScript.__gt__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.TestAndRebuildScript.TestAndRebuildScript.TestAndRebuildScript.__le__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.TestAndRebuildScript.TestAndRebuildScript.TestAndRebuildScript.__lt__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.TestAndRebuildScript.TestAndRebuildScript.TestAndRebuildScript.__ne__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.TestAndRebuildScript.TestAndRebuildScript.TestAndRebuildScript.__repr__
   :noindex:
